@@ -1,6 +1,6 @@
 from .api_client import OrthancApiClient
 from .exceptions import *
-from .helpers import generate_test_dicom_file
+from .helpers import *
 from .change import ChangeType, ResourceType
 from .study import Study, StudyInfo
 
